@@ -154,7 +154,7 @@ class DataSetsManager(ManagerMix):
 
         if is_datetime(data["date_time"]):
             data['date_time'] = data.date_time.dt.tz_localize(tz="UTC")
-            data["date_time"] = (data.date_time.values.astype(np.int64) / 10**9).astype(np.int64)
+            data["date_time"] = (data.date_time.values.astype(np.int64) / 10**9).astype(np.int64) - 3600
 
         out = []
         for index, row in data.iterrows():
