@@ -1,4 +1,4 @@
-from cgdb.recources.timeStep import TimeStep
+from cgdb.resources.timeStep import TimeStep
 from cgdb.utils.ManagerMix import ManagerMix
 
 
