@@ -41,8 +41,8 @@ class DataSets:
     def data(self, date_from: datetime = None, date_to: datetime = None):
         return self._client._data_sets_manager.get_data_set_data(self, date_from, date_to)
 
-    def post_data(self, data: pd.DataFrame):
-        return self._client._data_sets_manager.post_data_set_data2(data, self)
+    def post_data(self, data: pd.DataFrame, overwriteStrategy:str = None):
+        return self._client._data_sets_manager.post_data_set_data2(data, self, overwriteStrategy)
 
     def delete_data_set(self):
         return self._client._data_sets_manager.delete_data_set(self)
